# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property
from abc import abstractmethod

import winrt._winrt
import winrt.system
import winrt.windows.data.xml.dom as windows_data_xml_dom
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.security.credentials as windows_security_credentials

from winrt.windows.web.syndication import SyndicationErrorStatus, SyndicationFormat, SyndicationTextType

Self = typing.TypeVar('Self')

@typing.final
class RetrievalProgress:
    @_property
    def bytes_retrieved(self) -> winrt.system.UInt32: ...
    @_property
    def total_bytes_to_retrieve(self) -> winrt.system.UInt32: ...
    def __new__(cls, bytes_retrieved: winrt.system.UInt32 = 0, total_bytes_to_retrieve: winrt.system.UInt32 = 0) -> RetrievalProgress: ...
    def __replace__(self, /, **changes: typing.Any) -> RetrievalProgress: ...
    def unpack(self) -> typing.Tuple[winrt.system.UInt32, winrt.system.UInt32]: ...

@typing.final
class TransferProgress:
    @_property
    def bytes_sent(self) -> winrt.system.UInt32: ...
    @_property
    def total_bytes_to_send(self) -> winrt.system.UInt32: ...
    @_property
    def bytes_retrieved(self) -> winrt.system.UInt32: ...
    @_property
    def total_bytes_to_retrieve(self) -> winrt.system.UInt32: ...
    def __new__(cls, bytes_sent: winrt.system.UInt32 = 0, total_bytes_to_send: winrt.system.UInt32 = 0, bytes_retrieved: winrt.system.UInt32 = 0, total_bytes_to_retrieve: winrt.system.UInt32 = 0) -> TransferProgress: ...
    def __replace__(self, /, **changes: typing.Any) -> TransferProgress: ...
    def unpack(self) -> typing.Tuple[winrt.system.UInt32, winrt.system.UInt32, winrt.system.UInt32, winrt.system.UInt32]: ...

@typing.final
class SyndicationAttribute(winrt.system.Object):
    @typing.overload
    def __new__(cls: typing.Type[Self], attribute_name: str, attribute_namespace: str, attribute_value: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.String Windows.Web.Syndication.SyndicationAttribute::get_Value()
    @_property
    def value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationAttribute::put_Value(System.String)
    @value.setter
    def value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationAttribute::get_Namespace()
    @_property
    def namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationAttribute::put_Namespace(System.String)
    @namespace.setter
    def namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationAttribute::get_Name()
    @_property
    def name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationAttribute::put_Name(System.String)
    @name.setter
    def name(self, value: str) -> None: ...

@typing.final
class SyndicationCategory(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], term: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self], term: str, scheme: str, label: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationCategory::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_Term()
    @_property
    def term(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_Term(System.String)
    @term.setter
    def term(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_Scheme()
    @_property
    def scheme(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_Scheme(System.String)
    @scheme.setter
    def scheme(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_Label()
    @_property
    def label(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_Label(System.String)
    @label.setter
    def label(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationCategory::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationCategory::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationCategory::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationCategory::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationCategory::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...

@typing.final
class SyndicationClient(winrt.system.Object, ISyndicationClient):
    @typing.overload
    def __new__(cls: typing.Type[Self], server_credential: windows_security_credentials.PasswordCredential) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Foundation.IAsyncOperationWithProgress`2<Windows.Web.Syndication.SyndicationFeed,Windows.Web.Syndication.RetrievalProgress> Windows.Web.Syndication.SyndicationClient::RetrieveFeedAsync(Windows.Foundation.Uri)
    def retrieve_feed_async(self, uri: windows_foundation.Uri, /) -> windows_foundation.IAsyncOperationWithProgress[SyndicationFeed, RetrievalProgress]: ...
    # System.Void Windows.Web.Syndication.SyndicationClient::SetRequestHeader(System.String,System.String)
    def set_request_header(self, name: str, value: str, /) -> None: ...
    # System.UInt32 Windows.Web.Syndication.SyndicationClient::get_Timeout()
    @_property
    def timeout(self) -> winrt.system.UInt32: ...
    # System.Void Windows.Web.Syndication.SyndicationClient::put_Timeout(System.UInt32)
    @timeout.setter
    def timeout(self, value: winrt.system.UInt32) -> None: ...
    # Windows.Security.Credentials.PasswordCredential Windows.Web.Syndication.SyndicationClient::get_ServerCredential()
    @_property
    def server_credential(self) -> windows_security_credentials.PasswordCredential: ...
    # System.Void Windows.Web.Syndication.SyndicationClient::put_ServerCredential(Windows.Security.Credentials.PasswordCredential)
    @server_credential.setter
    def server_credential(self, value: windows_security_credentials.PasswordCredential) -> None: ...
    # Windows.Security.Credentials.PasswordCredential Windows.Web.Syndication.SyndicationClient::get_ProxyCredential()
    @_property
    def proxy_credential(self) -> windows_security_credentials.PasswordCredential: ...
    # System.Void Windows.Web.Syndication.SyndicationClient::put_ProxyCredential(Windows.Security.Credentials.PasswordCredential)
    @proxy_credential.setter
    def proxy_credential(self, value: windows_security_credentials.PasswordCredential) -> None: ...
    # System.UInt32 Windows.Web.Syndication.SyndicationClient::get_MaxResponseBufferSize()
    @_property
    def max_response_buffer_size(self) -> winrt.system.UInt32: ...
    # System.Void Windows.Web.Syndication.SyndicationClient::put_MaxResponseBufferSize(System.UInt32)
    @max_response_buffer_size.setter
    def max_response_buffer_size(self, value: winrt.system.UInt32) -> None: ...
    # System.Boolean Windows.Web.Syndication.SyndicationClient::get_BypassCacheOnRetrieve()
    @_property
    def bypass_cache_on_retrieve(self) -> bool: ...
    # System.Void Windows.Web.Syndication.SyndicationClient::put_BypassCacheOnRetrieve(System.Boolean)
    @bypass_cache_on_retrieve.setter
    def bypass_cache_on_retrieve(self, value: bool) -> None: ...

@typing.final
class SyndicationContent(winrt.system.Object, ISyndicationText, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], text: str, type: SyndicationTextType) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self], source_uri: windows_foundation.Uri) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationContent::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationContent::get_SourceUri()
    @_property
    def source_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_SourceUri(Windows.Foundation.Uri)
    @source_uri.setter
    def source_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationContent::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationContent::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationContent::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationContent::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationContent::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationContent::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationContent::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...
    # System.String Windows.Web.Syndication.SyndicationContent::get_Text()
    @_property
    def text(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_Text(System.String)
    @text.setter
    def text(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationContent::get_Type()
    @_property
    def type(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_Type(System.String)
    @type.setter
    def type(self, value: str) -> None: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationContent::get_Xml()
    @_property
    def xml(self) -> windows_data_xml_dom.XmlDocument: ...
    # System.Void Windows.Web.Syndication.SyndicationContent::put_Xml(Windows.Data.Xml.Dom.XmlDocument)
    @xml.setter
    def xml(self, value: windows_data_xml_dom.XmlDocument) -> None: ...

@typing.final
class SyndicationError_Static(winrt._winrt.IInspectable_Static):
    # Windows.Web.Syndication.SyndicationErrorStatus Windows.Web.Syndication.SyndicationError::GetStatus(System.Int32)
    def get_status(cls, hresult: winrt.system.Int32, /) -> SyndicationErrorStatus: ...

@typing.final
class SyndicationError(winrt.system.Object, metaclass=SyndicationError_Static):
    pass

@typing.final
class SyndicationFeed(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], title: str, subtitle: str, uri: windows_foundation.Uri) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationFeed::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::Load(System.String)
    def load(self, feed: str, /) -> None: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::LoadFromXml(Windows.Data.Xml.Dom.XmlDocument)
    def load_from_xml(self, feed_document: windows_data_xml_dom.XmlDocument, /) -> None: ...
    # Windows.Web.Syndication.ISyndicationText Windows.Web.Syndication.SyndicationFeed::get_Title()
    @_property
    def title(self) -> ISyndicationText: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_Title(Windows.Web.Syndication.ISyndicationText)
    @title.setter
    def title(self, value: ISyndicationText) -> None: ...
    # Windows.Web.Syndication.ISyndicationText Windows.Web.Syndication.SyndicationFeed::get_Subtitle()
    @_property
    def subtitle(self) -> ISyndicationText: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_Subtitle(Windows.Web.Syndication.ISyndicationText)
    @subtitle.setter
    def subtitle(self, value: ISyndicationText) -> None: ...
    # Windows.Web.Syndication.ISyndicationText Windows.Web.Syndication.SyndicationFeed::get_Rights()
    @_property
    def rights(self) -> ISyndicationText: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_Rights(Windows.Web.Syndication.ISyndicationText)
    @rights.setter
    def rights(self, value: ISyndicationText) -> None: ...
    # Windows.Web.Syndication.SyndicationGenerator Windows.Web.Syndication.SyndicationFeed::get_Generator()
    @_property
    def generator(self) -> SyndicationGenerator: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_Generator(Windows.Web.Syndication.SyndicationGenerator)
    @generator.setter
    def generator(self, value: SyndicationGenerator) -> None: ...
    # Windows.Foundation.DateTime Windows.Web.Syndication.SyndicationFeed::get_LastUpdatedTime()
    @_property
    def last_updated_time(self) -> datetime.datetime: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_LastUpdatedTime(Windows.Foundation.DateTime)
    @last_updated_time.setter
    def last_updated_time(self, value: datetime.datetime) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_ImageUri()
    @_property
    def image_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_ImageUri(Windows.Foundation.Uri)
    @image_uri.setter
    def image_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_IconUri()
    @_property
    def icon_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_IconUri(Windows.Foundation.Uri)
    @icon_uri.setter
    def icon_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationFeed::get_Id()
    @_property
    def id(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_Id(System.String)
    @id.setter
    def id(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_FirstUri()
    @_property
    def first_uri(self) -> windows_foundation.Uri: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationItem> Windows.Web.Syndication.SyndicationFeed::get_Items()
    @_property
    def items(self) -> typing.MutableSequence[SyndicationItem]: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_LastUri()
    @_property
    def last_uri(self) -> windows_foundation.Uri: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationLink> Windows.Web.Syndication.SyndicationFeed::get_Links()
    @_property
    def links(self) -> typing.MutableSequence[SyndicationLink]: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_NextUri()
    @_property
    def next_uri(self) -> windows_foundation.Uri: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_PreviousUri()
    @_property
    def previous_uri(self) -> windows_foundation.Uri: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationCategory> Windows.Web.Syndication.SyndicationFeed::get_Categories()
    @_property
    def categories(self) -> typing.MutableSequence[SyndicationCategory]: ...
    # Windows.Web.Syndication.SyndicationFormat Windows.Web.Syndication.SyndicationFeed::get_SourceFormat()
    @_property
    def source_format(self) -> SyndicationFormat: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationPerson> Windows.Web.Syndication.SyndicationFeed::get_Contributors()
    @_property
    def contributors(self) -> typing.MutableSequence[SyndicationPerson]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationPerson> Windows.Web.Syndication.SyndicationFeed::get_Authors()
    @_property
    def authors(self) -> typing.MutableSequence[SyndicationPerson]: ...
    # System.String Windows.Web.Syndication.SyndicationFeed::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationFeed::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationFeed::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationFeed::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationFeed::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationFeed::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationFeed::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationFeed::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...

@typing.final
class SyndicationGenerator(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], text: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationGenerator::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.String Windows.Web.Syndication.SyndicationGenerator::get_Version()
    @_property
    def version(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_Version(System.String)
    @version.setter
    def version(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationGenerator::get_Uri()
    @_property
    def uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_Uri(Windows.Foundation.Uri)
    @uri.setter
    def uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationGenerator::get_Text()
    @_property
    def text(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_Text(System.String)
    @text.setter
    def text(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationGenerator::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationGenerator::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationGenerator::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationGenerator::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationGenerator::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationGenerator::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationGenerator::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationGenerator::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...

@typing.final
class SyndicationItem(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], title: str, content: SyndicationContent, uri: windows_foundation.Uri) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationItem::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::Load(System.String)
    def load(self, item: str, /) -> None: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::LoadFromXml(Windows.Data.Xml.Dom.XmlDocument)
    def load_from_xml(self, item_document: windows_data_xml_dom.XmlDocument, /) -> None: ...
    # Windows.Web.Syndication.ISyndicationText Windows.Web.Syndication.SyndicationItem::get_Title()
    @_property
    def title(self) -> ISyndicationText: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Title(Windows.Web.Syndication.ISyndicationText)
    @title.setter
    def title(self, value: ISyndicationText) -> None: ...
    # Windows.Web.Syndication.SyndicationFeed Windows.Web.Syndication.SyndicationItem::get_Source()
    @_property
    def source(self) -> SyndicationFeed: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Source(Windows.Web.Syndication.SyndicationFeed)
    @source.setter
    def source(self, value: SyndicationFeed) -> None: ...
    # Windows.Web.Syndication.ISyndicationText Windows.Web.Syndication.SyndicationItem::get_Rights()
    @_property
    def rights(self) -> ISyndicationText: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Rights(Windows.Web.Syndication.ISyndicationText)
    @rights.setter
    def rights(self, value: ISyndicationText) -> None: ...
    # Windows.Web.Syndication.ISyndicationText Windows.Web.Syndication.SyndicationItem::get_Summary()
    @_property
    def summary(self) -> ISyndicationText: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Summary(Windows.Web.Syndication.ISyndicationText)
    @summary.setter
    def summary(self, value: ISyndicationText) -> None: ...
    # Windows.Foundation.DateTime Windows.Web.Syndication.SyndicationItem::get_PublishedDate()
    @_property
    def published_date(self) -> datetime.datetime: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_PublishedDate(Windows.Foundation.DateTime)
    @published_date.setter
    def published_date(self, value: datetime.datetime) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationItem::get_CommentsUri()
    @_property
    def comments_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_CommentsUri(Windows.Foundation.Uri)
    @comments_uri.setter
    def comments_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationItem::get_Id()
    @_property
    def id(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Id(System.String)
    @id.setter
    def id(self, value: str) -> None: ...
    # Windows.Foundation.DateTime Windows.Web.Syndication.SyndicationItem::get_LastUpdatedTime()
    @_property
    def last_updated_time(self) -> datetime.datetime: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_LastUpdatedTime(Windows.Foundation.DateTime)
    @last_updated_time.setter
    def last_updated_time(self, value: datetime.datetime) -> None: ...
    # Windows.Web.Syndication.SyndicationContent Windows.Web.Syndication.SyndicationItem::get_Content()
    @_property
    def content(self) -> SyndicationContent: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Content(Windows.Web.Syndication.SyndicationContent)
    @content.setter
    def content(self, value: SyndicationContent) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationItem::get_EditUri()
    @_property
    def edit_uri(self) -> windows_foundation.Uri: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationLink> Windows.Web.Syndication.SyndicationItem::get_Links()
    @_property
    def links(self) -> typing.MutableSequence[SyndicationLink]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationPerson> Windows.Web.Syndication.SyndicationItem::get_Authors()
    @_property
    def authors(self) -> typing.MutableSequence[SyndicationPerson]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationCategory> Windows.Web.Syndication.SyndicationItem::get_Categories()
    @_property
    def categories(self) -> typing.MutableSequence[SyndicationCategory]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationPerson> Windows.Web.Syndication.SyndicationItem::get_Contributors()
    @_property
    def contributors(self) -> typing.MutableSequence[SyndicationPerson]: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationItem::get_ItemUri()
    @_property
    def item_uri(self) -> windows_foundation.Uri: ...
    # System.String Windows.Web.Syndication.SyndicationItem::get_ETag()
    @_property
    def e_tag(self) -> str: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationItem::get_EditMediaUri()
    @_property
    def edit_media_uri(self) -> windows_foundation.Uri: ...
    # System.String Windows.Web.Syndication.SyndicationItem::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationItem::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationItem::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationItem::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationItem::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationItem::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationItem::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationItem::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...

@typing.final
class SyndicationLink(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], uri: windows_foundation.Uri) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self], uri: windows_foundation.Uri, relationship: str, title: str, media_type: str, length: winrt.system.UInt32) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationLink::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationLink::get_Uri()
    @_property
    def uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_Uri(Windows.Foundation.Uri)
    @uri.setter
    def uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_Title()
    @_property
    def title(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_Title(System.String)
    @title.setter
    def title(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_ResourceLanguage()
    @_property
    def resource_language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_ResourceLanguage(System.String)
    @resource_language.setter
    def resource_language(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_Relationship()
    @_property
    def relationship(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_Relationship(System.String)
    @relationship.setter
    def relationship(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_MediaType()
    @_property
    def media_type(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_MediaType(System.String)
    @media_type.setter
    def media_type(self, value: str) -> None: ...
    # System.UInt32 Windows.Web.Syndication.SyndicationLink::get_Length()
    @_property
    def length(self) -> winrt.system.UInt32: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_Length(System.UInt32)
    @length.setter
    def length(self, value: winrt.system.UInt32) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationLink::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationLink::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationLink::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationLink::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationLink::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...

@typing.final
class SyndicationNode(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], node_name: str, node_namespace: str, node_value: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationNode::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.String Windows.Web.Syndication.SyndicationNode::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationNode::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationNode::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationNode::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationNode::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationNode::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationNode::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationNode::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationNode::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationNode::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationNode::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationNode::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...

@typing.final
class SyndicationPerson(winrt.system.Object, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], name: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self], name: str, email: str, uri: windows_foundation.Uri) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationPerson::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.String Windows.Web.Syndication.SyndicationPerson::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationPerson::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationPerson::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationPerson::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationPerson::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationPerson::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationPerson::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationPerson::get_Uri()
    @_property
    def uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_Uri(Windows.Foundation.Uri)
    @uri.setter
    def uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationPerson::get_Name()
    @_property
    def name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_Name(System.String)
    @name.setter
    def name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationPerson::get_Email()
    @_property
    def email(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationPerson::put_Email(System.String)
    @email.setter
    def email(self, value: str) -> None: ...

@typing.final
class SyndicationText(winrt.system.Object, ISyndicationText, ISyndicationNode):
    @typing.overload
    def __new__(cls: typing.Type[Self], text: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self], text: str, type: SyndicationTextType) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationText::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # System.String Windows.Web.Syndication.SyndicationText::get_NodeValue()
    @_property
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_NodeValue(System.String)
    @node_value.setter
    def node_value(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationText::get_NodeNamespace()
    @_property
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_NodeNamespace(System.String)
    @node_namespace.setter
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationText::get_NodeName()
    @_property
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_NodeName(System.String)
    @node_name.setter
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationText::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.SyndicationText::get_BaseUri()
    @_property
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.SyndicationText::get_AttributeExtensions()
    @_property
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.SyndicationText::get_ElementExtensions()
    @_property
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.SyndicationText::get_Xml()
    @_property
    def xml(self) -> windows_data_xml_dom.XmlDocument: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_Xml(Windows.Data.Xml.Dom.XmlDocument)
    @xml.setter
    def xml(self, value: windows_data_xml_dom.XmlDocument) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationText::get_Type()
    @_property
    def type(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_Type(System.String)
    @type.setter
    def type(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.SyndicationText::get_Text()
    @_property
    def text(self) -> str: ...
    # System.Void Windows.Web.Syndication.SyndicationText::put_Text(System.String)
    @text.setter
    def text(self, value: str) -> None: ...

@typing.final
class _ISyndicationClient: ...

class ISyndicationClient(winrt._winrt.IInspectable):
    # Windows.Foundation.IAsyncOperationWithProgress`2<Windows.Web.Syndication.SyndicationFeed,Windows.Web.Syndication.RetrievalProgress> Windows.Web.Syndication.ISyndicationClient::RetrieveFeedAsync(Windows.Foundation.Uri)
    @abstractmethod
    def retrieve_feed_async(self, uri: windows_foundation.Uri, /) -> windows_foundation.IAsyncOperationWithProgress[SyndicationFeed, RetrievalProgress]: ...
    # System.Void Windows.Web.Syndication.ISyndicationClient::SetRequestHeader(System.String,System.String)
    @abstractmethod
    def set_request_header(self, name: str, value: str, /) -> None: ...
    # System.Boolean Windows.Web.Syndication.ISyndicationClient::get_BypassCacheOnRetrieve()
    @_property
    @abstractmethod
    def bypass_cache_on_retrieve(self) -> bool: ...
    # System.Void Windows.Web.Syndication.ISyndicationClient::put_BypassCacheOnRetrieve(System.Boolean)
    @bypass_cache_on_retrieve.setter
    @abstractmethod
    def bypass_cache_on_retrieve(self, value: bool) -> None: ...
    # System.UInt32 Windows.Web.Syndication.ISyndicationClient::get_MaxResponseBufferSize()
    @_property
    @abstractmethod
    def max_response_buffer_size(self) -> winrt.system.UInt32: ...
    # System.Void Windows.Web.Syndication.ISyndicationClient::put_MaxResponseBufferSize(System.UInt32)
    @max_response_buffer_size.setter
    @abstractmethod
    def max_response_buffer_size(self, value: winrt.system.UInt32) -> None: ...
    # Windows.Security.Credentials.PasswordCredential Windows.Web.Syndication.ISyndicationClient::get_ProxyCredential()
    @_property
    @abstractmethod
    def proxy_credential(self) -> windows_security_credentials.PasswordCredential: ...
    # System.Void Windows.Web.Syndication.ISyndicationClient::put_ProxyCredential(Windows.Security.Credentials.PasswordCredential)
    @proxy_credential.setter
    @abstractmethod
    def proxy_credential(self, value: windows_security_credentials.PasswordCredential) -> None: ...
    # Windows.Security.Credentials.PasswordCredential Windows.Web.Syndication.ISyndicationClient::get_ServerCredential()
    @_property
    @abstractmethod
    def server_credential(self) -> windows_security_credentials.PasswordCredential: ...
    # System.Void Windows.Web.Syndication.ISyndicationClient::put_ServerCredential(Windows.Security.Credentials.PasswordCredential)
    @server_credential.setter
    @abstractmethod
    def server_credential(self, value: windows_security_credentials.PasswordCredential) -> None: ...
    # System.UInt32 Windows.Web.Syndication.ISyndicationClient::get_Timeout()
    @_property
    @abstractmethod
    def timeout(self) -> winrt.system.UInt32: ...
    # System.Void Windows.Web.Syndication.ISyndicationClient::put_Timeout(System.UInt32)
    @timeout.setter
    @abstractmethod
    def timeout(self, value: winrt.system.UInt32) -> None: ...

@typing.final
class _ISyndicationNode: ...

class ISyndicationNode(winrt._winrt.IInspectable):
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.ISyndicationNode::GetXmlDocument(Windows.Web.Syndication.SyndicationFormat)
    @abstractmethod
    def get_xml_document(self, format: SyndicationFormat, /) -> windows_data_xml_dom.XmlDocument: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.SyndicationAttribute> Windows.Web.Syndication.ISyndicationNode::get_AttributeExtensions()
    @_property
    @abstractmethod
    def attribute_extensions(self) -> typing.MutableSequence[SyndicationAttribute]: ...
    # Windows.Foundation.Uri Windows.Web.Syndication.ISyndicationNode::get_BaseUri()
    @_property
    @abstractmethod
    def base_uri(self) -> windows_foundation.Uri: ...
    # System.Void Windows.Web.Syndication.ISyndicationNode::put_BaseUri(Windows.Foundation.Uri)
    @base_uri.setter
    @abstractmethod
    def base_uri(self, value: windows_foundation.Uri) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Windows.Web.Syndication.ISyndicationNode> Windows.Web.Syndication.ISyndicationNode::get_ElementExtensions()
    @_property
    @abstractmethod
    def element_extensions(self) -> typing.MutableSequence[ISyndicationNode]: ...
    # System.String Windows.Web.Syndication.ISyndicationNode::get_Language()
    @_property
    @abstractmethod
    def language(self) -> str: ...
    # System.Void Windows.Web.Syndication.ISyndicationNode::put_Language(System.String)
    @language.setter
    @abstractmethod
    def language(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.ISyndicationNode::get_NodeName()
    @_property
    @abstractmethod
    def node_name(self) -> str: ...
    # System.Void Windows.Web.Syndication.ISyndicationNode::put_NodeName(System.String)
    @node_name.setter
    @abstractmethod
    def node_name(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.ISyndicationNode::get_NodeNamespace()
    @_property
    @abstractmethod
    def node_namespace(self) -> str: ...
    # System.Void Windows.Web.Syndication.ISyndicationNode::put_NodeNamespace(System.String)
    @node_namespace.setter
    @abstractmethod
    def node_namespace(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.ISyndicationNode::get_NodeValue()
    @_property
    @abstractmethod
    def node_value(self) -> str: ...
    # System.Void Windows.Web.Syndication.ISyndicationNode::put_NodeValue(System.String)
    @node_value.setter
    @abstractmethod
    def node_value(self, value: str) -> None: ...

@typing.final
class _ISyndicationText: ...

class ISyndicationText(ISyndicationNode, winrt._winrt.IInspectable):
    # System.String Windows.Web.Syndication.ISyndicationText::get_Text()
    @_property
    @abstractmethod
    def text(self) -> str: ...
    # System.Void Windows.Web.Syndication.ISyndicationText::put_Text(System.String)
    @text.setter
    @abstractmethod
    def text(self, value: str) -> None: ...
    # System.String Windows.Web.Syndication.ISyndicationText::get_Type()
    @_property
    @abstractmethod
    def type(self) -> str: ...
    # System.Void Windows.Web.Syndication.ISyndicationText::put_Type(System.String)
    @type.setter
    @abstractmethod
    def type(self, value: str) -> None: ...
    # Windows.Data.Xml.Dom.XmlDocument Windows.Web.Syndication.ISyndicationText::get_Xml()
    @_property
    @abstractmethod
    def xml(self) -> windows_data_xml_dom.XmlDocument: ...
    # System.Void Windows.Web.Syndication.ISyndicationText::put_Xml(Windows.Data.Xml.Dom.XmlDocument)
    @xml.setter
    @abstractmethod
    def xml(self, value: windows_data_xml_dom.XmlDocument) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import enum

import winrt.system
from winrt._winrt_windows_web_syndication import (
    RetrievalProgress,
    TransferProgress,
    SyndicationAttribute,
    SyndicationCategory,
    SyndicationClient,
    SyndicationContent,
    SyndicationError,
    SyndicationFeed,
    SyndicationGenerator,
    SyndicationItem,
    SyndicationLink,
    SyndicationNode,
    SyndicationPerson,
    SyndicationText,
    _ISyndicationClient,
    ISyndicationClient,
    _ISyndicationNode,
    ISyndicationNode,
    _ISyndicationText,
    ISyndicationText,
)

__all__ = [
    "SyndicationErrorStatus",
    "SyndicationFormat",
    "SyndicationTextType",
    "RetrievalProgress",
    "TransferProgress",
    "SyndicationAttribute",
    "SyndicationCategory",
    "SyndicationClient",
    "SyndicationContent",
    "SyndicationError",
    "SyndicationFeed",
    "SyndicationGenerator",
    "SyndicationItem",
    "SyndicationLink",
    "SyndicationNode",
    "SyndicationPerson",
    "SyndicationText",
    "ISyndicationClient",
    "ISyndicationNode",
    "ISyndicationText",
]

class SyndicationErrorStatus(enum.IntEnum):
    UNKNOWN = 0
    MISSING_REQUIRED_ELEMENT = 1
    MISSING_REQUIRED_ATTRIBUTE = 2
    INVALID_XML = 3
    UNEXPECTED_CONTENT = 4
    UNSUPPORTED_FORMAT = 5

class SyndicationFormat(enum.IntEnum):
    ATOM10 = 0
    RSS20 = 1
    RSS10 = 2
    RSS092 = 3
    RSS091 = 4
    ATOM03 = 5

class SyndicationTextType(enum.IntEnum):
    TEXT = 0
    HTML = 1
    XHTML = 2

